@@ -10,15 +10,15 @@ use Exporter;
 use Storable;
 use Symbol qw(delete_package);
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
-                    trace
-                    trace_dump
-                    install_trace
-                    remove_trace
-                );
+    trace
+    trace_dump
+    install_trace
+    remove_trace
+);
 
 $SIG{INT} = sub { 'this ensures END runs if ^C is pressed'; };
 
@@ -35,9 +35,9 @@ sub trace {
     my $flow_count = ++$ENV{DTS_FLOW_COUNT};
 
     my $flow = {
-                 name => $flow_count,
-                 value => (caller(1))[3] || 'main()'
-               };
+        name => $flow_count,
+        value => (caller(1))[3] || 'main()'
+    };
 
     push @{$data->{flow}}, $flow;
 
@@ -139,9 +139,9 @@ sub install_trace {
 
     my %p = @_;
 
-    my $file = $p{file};
-    my $extensions = $p{extensions};
-    my $inject = $p{inject};
+    my $file        = $p{file};
+    my $extensions  = $p{extensions};
+    my $inject      = $p{inject};
 
     my $des_use = Devel::Examine::Subs->new(file => $file,);
 
@@ -152,9 +152,9 @@ sub install_trace {
     $des_use->inject(inject_use => _inject_use());
 
     my $des = Devel::Examine::Subs->new(
-                                        file => $file,
-                                        extensions => $extensions,
-                                     );
+        file        => $file,
+        extensions  => $extensions,
+    );
 
     $inject = $p{inject} || _inject_code();
 
@@ -176,8 +176,8 @@ sub remove_trace {
         die "Devel::Examine::Subs isn't installed. Can't run remove_trace(): $@";
     }
    
-    my %p = @_;
-    my $file = $p{file};
+    my %p       = @_;
+    my $file    = $p{file};
 
     my $des = Devel::Examine::Subs->new( file => $file ); 
 
@@ -203,7 +203,7 @@ sub _env {
 }
 sub _store {
 
-    my $data = shift;
+    my ($data) = @_;
 
     my $store = "DTS_" . join('_', ($$ x 3)) . ".dat";
 
@@ -236,8 +236,8 @@ __END__
 Devel::Trace::Subs - Generate, track, store and print code flow and stack traces
 
 =for html
-<a href="https://github.com/stevieb9/devel-examine-subs/actions"><img src="https://github.com/stevieb9/devel-examine-subs/workflows/CI/badge.svg"/></a>
-<a href='https://coveralls.io/github/stevieb9/devel-examine-subs?branch=master'><img src='https://coveralls.io/repos/stevieb9/devel-examine-subs/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
+<a href="https://github.com/stevieb9/devel-trace-subs/actions"><img src="https://github.com/stevieb9/devel-trace-subs/workflows/CI/badge.svg"/></a>
+<a href='https://coveralls.io/github/stevieb9/devel-trace-subs?branch=master'><img src='https://coveralls.io/repos/stevieb9/devel-trace-subs/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
 
 =head1 SYNOPSIS
 
@@ -314,13 +314,13 @@ program is having trouble, but the program itself isn't outputting anything usef
 
 Parameters:
 
-    want    => 'flow'|'stack'
+    want => 'flow'|'stack'
 
 Optional, String: Display either the code flow or stack trace.
 
 Default: None (display both flow and trace information).
 
-    type    => 'html'
+    type => 'html'
 
 Optional, String: The display output format. Only valid value is C<html>.
 
